TriangulationMethod

Enum TriangulationMethod 

pub enum TriangulationMethod {
    Linear,
    CloughTocher,
    NearestVertex,
}
Interpolation method for triangulation-based interpolation

Variants



Linear

Linear (barycentric) interpolation within each triangle

C0 continuous. The interpolated surface is a piecewise planar surface over the triangulation.



CloughTocher

Clough-Tocher C1 smooth interpolation

Subdivides each triangle into 3 sub-triangles and uses cubic Bernstein polynomials for C1 continuity. Gradient estimation at vertices uses least-squares fitting.



NearestVertex

Nearest vertex interpolation

Returns the value of the nearest vertex of the enclosing triangle. Piecewise constant within each Voronoi cell.